@@ -23,22 +23,22 @@
 #include "redmond_gtk2_drawing.h"
 #include "redmond_gtk2_misc.h"
  
-static guchar radio_base_bits[] = {
+static char radio_base_bits[] = {
   0x00,0x00,0x00,0x00,0xf0,0x01,0xf8,0x03,0xfc,0x07,0xfc,0x07,0xfc,0x07,0xfc,
   0x07,0xfc,0x07,0xf8,0x03,0xf0,0x01,0x00,0x00,0x00,0x00,0x00,0x00};
-static guchar radio_black_bits[] = {
+static char radio_black_bits[] = {
   0x00,0x00,0xf0,0x01,0x0c,0x02,0x04,0x00,0x02,0x00,0x02,0x00,0x02,0x00,0x02,
   0x00,0x02,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0d,0x08};
-static guchar radio_dark_bits[] = {
+static char radio_dark_bits[] = {
   0xf0,0x00,0x0c,0x02,0x02,0x00,0x02,0x00,0x01,0x00,0x01,0x00,0x01,0x00,0x01,
   0x00,0x00,0x00,0x02,0x00,0x0c,0x00,0x00,0x00,0x00,0x00,0x00,0x00};
-static guchar radio_light_bits[] = {
+static char radio_light_bits[] = {
   0x00,0x00,0x00,0x04,0x00,0x08,0x00,0x08,0x00,0x10,0x00,0x10,0x00,0x10,0x00,
   0x10,0x00,0x10,0x00,0x08,0x00,0x08,0x08,0x06,0xf0,0x01,0x00,0x00};
-static guchar radio_mid_bits[] = {
+static char radio_mid_bits[] = {
   0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x04,0x00,0x08,0x00,0x08,0x00,0x08,0x00,
   0x08,0x00,0x08,0x00,0x04,0x00,0x06,0xf0,0x01,0x00,0x00,0x00,0x00};
-static guchar radio_text_bits[] = {
+static char radio_text_bits[] = {
   0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xe0,0x00,0xf0,0x01,0xf0,0x01,0xf0,
   0x01,0xe0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00};
  
@@ -162,7 +162,7 @@ is_toolbar_item (GtkWidget * widget)
 {
   gboolean result = FALSE;
  
-  if ((widget) && (widget->parent))
+  if ((widget) && (widget->parent)) {
     if ((IS_BONOBO_TOOLBAR (widget->parent))
 	|| (IS_BONOBO_DOCK_ITEM (widget->parent))
 	|| (IS_EGG_TOOLBAR (widget->parent))
@@ -171,7 +171,7 @@ is_toolbar_item (GtkWidget * widget)
       result = TRUE;
     else
       result = is_toolbar_item (widget->parent);
- 
+  }
   return result;
 }
  
@@ -1089,8 +1089,6 @@ gtk_menu_shell_setup_signals(GtkWidget *widget)
  
       if (!g_object_get_data(G_OBJECT(widget), "REDMOND_MENU_SHELL_HACK_SET"))
       {
-        GList *list = NULL;
- 
         id = g_signal_connect(G_OBJECT(widget), "motion-notify-event",
                                              (GtkSignalFunc)gtk_menu_shell_motion,
                                              NULL);
@@ -1128,7 +1126,6 @@ gtk_menu_shell_cleanup_signals(GtkWidget *widget)
   if (IS_MENU_BAR(widget))
     {
       gint id = 0;
-      GList *list = NULL, *item = NULL;
  
       id = (gint)g_object_steal_data (G_OBJECT(widget), "REDMOND_MENU_SHELL_MOTION_ID");
       g_signal_handler_disconnect(G_OBJECT(widget), id);
